@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2015-09-17'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,7 +45,7 @@ sub _default_completion {
             last if $@;
             my $res = Unix::Passwd::File::list_users(detail=>1);
             last unless $res->[0] == 200;
-            my $compres = Complete::Util::complete_array(
+            my $compres = Complete::Util::complete_array_elem(
                 array=>[map {"~" . $_->{user} . ((-d $_->{home}) ? "/":"")}
                             @{ $res->[2] }],
                 word=>$word,
@@ -197,7 +197,7 @@ Example:
             my $word  = $args{word};
             my $ospec = $args{ospec};
             if ($ospec && $ospec eq 'format=s') {
-                complete_array(array=>[qw/json text xml yaml/], word=>$word);
+                complete_array_elem(array=>[qw/json text xml yaml/], word=>$word);
             } else {
                 complete_user(word=>$word);
             }
@@ -584,7 +584,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.34 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-09-09.
+This document describes version 0.35 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-09-17.
 
 =head1 SYNOPSIS
 
@@ -689,7 +689,7 @@ Example:
          my $word  = $args{word};
          my $ospec = $args{ospec};
          if ($ospec && $ospec eq 'format=s') {
-             complete_array(array=>[qw/json text xml yaml/], word=>$word);
+             complete_array_elem(array=>[qw/json text xml yaml/], word=>$word);
          } else {
              complete_user(word=>$word);
          }
